==> kubernetes-model-1.0.31-sources.jar: io/fabric8/kubernetes/api/model/ContainerStateTerminatedFluentImpl.java <==
package io.fabric8.kubernetes.api.model;

import java.util.Map;
import java.util.HashMap;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import io.fabric8.kubernetes.api.builder.Fluent;

public class ContainerStateTerminatedFluentImpl<T extends ContainerStateTerminatedFluent<T>> extends BaseFluent<T> implements ContainerStateTerminatedFluent<T>{

     String containerID;     Integer exitCode;     String finishedAt;     String message;     String reason;     Integer signal;     String startedAt;     Map<String, Object> additionalProperties = new HashMap();

    public String getContainerID(){
    return this.containerID;
    }
    public T withContainerID( String containerID){
    this.containerID=containerID; return (T) this;
    }
    public Integer getExitCode(){
    return this.exitCode;
    }
    public T withExitCode( Integer exitCode){
    this.exitCode=exitCode; return (T) this;
    }
    public String getFinishedAt(){
    return this.finishedAt;
    }
    public T withFinishedAt( String finishedAt){
    this.finishedAt=finishedAt; return (T) this;
    }
    public String getMessage(){
    return this.message;
    }
    public T withMessage( String message){
    this.message=message; return (T) this;
    }
    public String getReason(){
    return this.reason;
    }
    public T withReason( String reason){
    this.reason=reason; return (T) this;
    }
    public Integer getSignal(){
    return this.signal;
    }
    public T withSignal( Integer signal){
    this.signal=signal; return (T) this;
    }
    public String getStartedAt(){
    return this.startedAt;
    }
    public T withStartedAt( String startedAt){
    this.startedAt=startedAt; return (T) this;
    }
    public T addToAdditionalProperties( String key,  Object value){
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (T)this;
    }
    public T addToAdditionalProperties( Map<String, Object> map){
    if(map != null) { this.additionalProperties.putAll(map);} return (T)this;
    }
    public T removeFromAdditionalProperties( String key){
    if(key != null) {this.additionalProperties.remove(key);} return (T)this;
    }
    public T removeFromAdditionalProperties( Map<String, Object> map){
    if(map != null) { for(Object key : map.keySet()) {this.additionalProperties.remove(key);}} return (T)this;
    }
    public Map<String, Object> getAdditionalProperties(){
    return this.additionalProperties;
    }
    public T withAdditionalProperties( Map<String, Object> additionalProperties){
    this.additionalProperties.clear();if (additionalProperties != null) {this.additionalProperties.putAll(additionalProperties);} return (T) this;
    }
    public boolean equals( Object o){
    
if (this == o) return true;
if (o == null || getClass() != o.getClass()) return false;
ContainerStateTerminatedFluentImpl that = (ContainerStateTerminatedFluentImpl) o;
if (containerID != null ? !containerID.equals(that.containerID) :that.containerID != null) return false;
if (exitCode != null ? !exitCode.equals(that.exitCode) :that.exitCode != null) return false;
if (finishedAt != null ? !finishedAt.equals(that.finishedAt) :that.finishedAt != null) return false;
if (message != null ? !message.equals(that.message) :that.message != null) return false;
if (reason != null ? !reason.equals(that.reason) :that.reason != null) return false;
if (signal != null ? !signal.equals(that.signal) :that.signal != null) return false;
if (startedAt != null ? !startedAt.equals(that.startedAt) :that.startedAt != null) return false;
if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
return true;

    }



}

==> kubernetes-model-1.0.40-sources.jar: io/fabric8/kubernetes/api/model/ContainerStateTerminatedFluentImpl.java <==
package io.fabric8.kubernetes.api.model;

import java.util.Map;
import java.util.HashMap;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import io.fabric8.kubernetes.api.builder.Fluent;

public class ContainerStateTerminatedFluentImpl<T extends ContainerStateTerminatedFluent<T>> extends BaseFluent<T> implements ContainerStateTerminatedFluent<T>{

     String containerID;     Integer exitCode;     String finishedAt;     String message;     String reason;     Integer signal;     String startedAt;     Map<String, Object> additionalProperties = new HashMap();
public ContainerStateTerminatedFluentImpl(){
    
}
public ContainerStateTerminatedFluentImpl( ContainerStateTerminated instance ){
    this.withContainerID(instance.getContainerID()); this.withExitCode(instance.getExitCode()); this.withFinishedAt(instance.getFinishedAt()); this.withMessage(instance.getMessage()); this.withReason(instance.getReason()); this.withSignal(instance.getSignal()); this.withStartedAt(instance.getStartedAt()); 
}

    public String getContainerID(){
    return this.containerID;
    }
    public T withContainerID( String containerID){
    this.containerID=containerID; return (T) this;
    }
    public Integer getExitCode(){
    return this.exitCode;
    }
    public T withExitCode( Integer exitCode){
    this.exitCode=exitCode; return (T) this;
    }
    public String getFinishedAt(){
    return this.finishedAt;
    }
    public T withFinishedAt( String finishedAt){
    this.finishedAt=finishedAt; return (T) this;
    }
    public String getMessage(){
    return this.message;
    }
    public T withMessage( String message){
    this.message=message; return (T) this;
    }
    public String getReason(){
    return this.reason;
    }
    public T withReason( String reason){
    this.reason=reason; return (T) this;
    }
    public Integer getSignal(){
    return this.signal;
    }
    public T withSignal( Integer signal){
    this.signal=signal; return (T) this;
    }
    public String getStartedAt(){
    return this.startedAt;
    }
    public T withStartedAt( String startedAt){
    this.startedAt=startedAt; return (T) this;
    }
    public T addToAdditionalProperties( String key,  Object value){
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (T)this;
    }
    public T addToAdditionalProperties( Map<String, Object> map){
    if(map != null) { this.additionalProperties.putAll(map);} return (T)this;
    }
    public T removeFromAdditionalProperties( String key){
    if(key != null) {this.additionalProperties.remove(key);} return (T)this;
    }
    public T removeFromAdditionalProperties( Map<String, Object> map){
    if(map != null) { for(Object key : map.keySet()) {this.additionalProperties.remove(key);}} return (T)this;
    }
    public Map<String, Object> getAdditionalProperties(){
    return this.additionalProperties;
    }
    public T withAdditionalProperties( Map<String, Object> additionalProperties){
    this.additionalProperties.clear();if (additionalProperties != null) {this.additionalProperties.putAll(additionalProperties);} return (T) this;
    }
    public boolean equals( Object o){
    
if (this == o) return true;
if (o == null || getClass() != o.getClass()) return false;
ContainerStateTerminatedFluentImpl that = (ContainerStateTerminatedFluentImpl) o;
if (containerID != null ? !containerID.equals(that.containerID) :that.containerID != null) return false;
if (exitCode != null ? !exitCode.equals(that.exitCode) :that.exitCode != null) return false;
if (finishedAt != null ? !finishedAt.equals(that.finishedAt) :that.finishedAt != null) return false;
if (message != null ? !message.equals(that.message) :that.message != null) return false;
if (reason != null ? !reason.equals(that.reason) :that.reason != null) return false;
if (signal != null ? !signal.equals(that.signal) :that.signal != null) return false;
if (startedAt != null ? !startedAt.equals(that.startedAt) :that.startedAt != null) return false;
if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
return true;

    }



}
